==> leonardo-0.4.0.tgz: leonardo-0.4.0/lib/templates/editform.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

page_title      = "%(site_title)s : EDIT %(page_title)s"
new_page_title  = "%(site_title)s: NEW PAGE"

new_page_content = "==%(resource_to_edit)s==\n\nType content here."

edit_form = """
<form action="%(post_action)s" method="POST">
  <textarea name="%(page_content_name)s" rows="25" cols="80">%(page_content)s</textarea>
  <br />
  <input type="hidden" name="%(resource_name)s" value="%(resource_to_edit)s" />
  <input type="submit" value="submit" />
</form>
<a href="%(cancel_action)s">Cancel</a>
"""

edit_menu = """
<p><a href="%(edit_page_href)s">Edit Page</a></p>
"""

edit_missing_id_title = "Missing Resource ID"
edit_missing_id_content = "Missing Resource ID."

edit_read_only_title = "Can't edit read-only resource"
edit_read_only_content = "Can't edit read-only resource."

==> leonardo-0.5b1.tgz: leonardo-0.5b1/lib/templates/editform.py <==
#
#    Copyright (C) 2003-2004  James Tauber
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

page_title      = "%(site_title)s : EDIT %(page_title)s"
new_page_title  = "%(site_title)s: NEW PAGE"

new_page_content = "==%(resource_to_edit)s==\n\nType content here."

edit_form = """
<form action="%(post_action)s" method="POST">
  <textarea name="%(page_content_name)s" rows="25" cols="80">%(page_content)s</textarea>
  <br />
  <input type="hidden" name="%(resource_name)s" value="%(resource_to_edit)s" />
  <input type="hidden" name="%(page_content_type_name)s" value="%(page_content_type)s" />
  <input type="submit" value="submit" /> as %(page_content_type)s
</form>
<a href="%(cancel_action)s">Cancel</a>
"""

edit_menu = """
<p><a href="%(edit_page_href)s">Edit Page</a></p>
"""

edit_missing_id_title = "Missing Resource ID"
edit_missing_id_content = "Missing Resource ID."

edit_read_only_title = "Can't edit read-only resource"
edit_read_only_content = "Can't edit read-only resource."
